@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::AutoReload;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 # ABSTRACT: Automatically reload open browser windows when your application changes
 
 #pod =head1 SYNOPSIS
@@ -63,7 +63,7 @@ sub register {
     $app->routes->websocket( '/auto_reload' => sub {
         my ( $c ) = @_;
         $c->inactivity_timeout( 60 );
-        my $timer_id = Mojo::IOLoop->timer( 30, sub { $c->send( 'ping' ) } );
+        my $timer_id = Mojo::IOLoop->recurring( 30, sub { $c->send( 'ping' ) } );
         $c->on( finish => sub {
             Mojo::IOLoop->remove( $timer_id );
         } );
@@ -83,7 +83,7 @@ sub register {
                     } );
                     // Send pings to ensure that the connection stays up, or we learn
                     // of the connection's death
-                    setInterval( function () { autoReloadWs.send( "ping" ) }, 5000 );
+                    setInterval( function () { autoReloadWs.send( "ping" ) }, 30000 );
                 </script>
 ENDHTML
         }
@@ -103,7 +103,7 @@ Mojolicious::Plugin::AutoReload - Automatically reload open browser windows when
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
